/**
 * Application configuration
 */
import React from 'react';
import DemoButton from './components/DemoButton';
import DemoEditor from './components/DemoEditor';
import { ProjectModel, TaskModel, MessageDialog } from '@bryntum/gantt';
import { nsUrl } from './config';
import { getParamUrl } from './util';

class MyTaskModel extends TaskModel {
    static get fields() {
        return [
            { name : 'durationUnit', defaultValue : 'hour' }
        ];
    }
}
const project_id = getParamUrl('id');
const project = new ProjectModel({
  taskModelClass : MyTaskModel,
  stm : {
      disabled : false,
      autoRecord : true
  },
  autoLoad: true,
  autoSync: true,
  autoSyncTimeout: 5000,
  transport: {
      load: {
          url: "http://localhost:3001/test"
      },
      sync : {
        url: "http://localhost:3001/sync"
      }
  },
  validateResponse : true
});

const ganttConfig = {
    //loadMask: null,
    syncMask: null,
    infiniteScroll : true,
    project,
    columns: [
        {
          editor: true, type: 'name', field: 'name', width: 250, renderer: ({record}) => {
            return record.isLeaf ? <span>{record.name}</span> : <b>{record.name}</b>
        }
      }
    ],
    viewPreset: 'weekAndDayLetter',
    barMargin: 10,
    features: {
        sort : 'order',
        pan: true,
        criticalPaths: true,
        cellEdit : {
            addNewAtEnd: true,
        },
        filter: true,
        taskEdit: {
            editorConfig : {
                listeners : {
                    show() {
                        //this.editor.widgetMap.manuallyScheduledField.hidden = true;

                        this.editor.widgetMap.effort.hidden = true;
                        this.editor.widgetMap.percentDone.hidden = true;
                        // this.editor.widgetMap.duration.hidden = true;
                        this.editor.widgetMap.endDate.disabled = true;

                        //this.editor.widgetMap.advancedTab.schedulingMode.value = "FixedDuration";
                    }
                }
            },
            items: {
                advancedTab: false,
                //successorsTab: false,
                resourcesTab: false,
                //notesTab: false,
                //predecessorsTab: false,
                generalTab: {
                    items: {
                        newGeneralField: {
                            type: "combo",
                            label: "START",
                            name: "constrainttypeNS",
                            items    : [{"value":"ASAP","text":"As Soon As Possible"},{"value":"FIXEDSTART","text":"Fixed Start"}],
                            onChange: (event) => {
                              if(event.value && event.value === "ASAP")
                                event.source.parent.widgetMap.startDate.disabled = true;
                              else
                                event.source.parent.widgetMap.startDate.disabled = false;
                            }
                        }
                    }
                }
            }
        },
        taskMenu : {
            items : {
                deleteTask : {
                    async onItem({ selection, taskRecord }) {
                        const store = this.owner.owner.project.taskStore;
                        const result = await MessageDialog.confirm({
                            title : 'Delete',
                            message : 'Are you sure, you want to delete this task?',
                            okButton : 'Yes',
                            cancelButton : 'No'
                        });
                        if (result === MessageDialog.okButton) {
                            store.remove(selection.includes(taskRecord) ? selection : taskRecord);
                        }
                    }
                }
            }
        }
    },
    listeners : {
  		taskMenuBeforeShow({ items }) {
        //items.add = false;

        //items.add.menu.subtask.hidden = true;
        //items.add.menu.milestone.hidden = true;
        items.add.menu.predecessor.hidden = true;
        items.add.menu.successor.hidden = true;

        items.convertToMilestone =false;
        items.copy = false;
        items.cut = false;
        items.indent = false;
        items.outdent = false;
        // items.deleteTask = false;
        items.filterStringEquals = false;
      },
      beforeCellEditStart({ editorContext : { record }, grid : gantt }) {
        // open task editor
        gantt.editTask(record);

        // prevent cell edit
        return false;
      }
  	},
    //onBeforeTaskSave: onBeforeTaskSave,
    //onBeforeTaskDelete: onBeforeTaskDelete
};

export { ganttConfig, project };
